#ifndef NT2_INCLUDE_CONSTANTS_RADINDEG_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_RADINDEG_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/radindeg.hpp>

#endif
